<?php

declare(strict_types=1);

namespace Drupal\Tests\verify_email\Functional;

use Drupal\Tests\BrowserTestBase;
use PHPUnit\Framework\Attributes\Group;

/**
 * Test description.
 */
#[Group('verify_email')]
final class VerifyEmailSetupTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['verify_email'];

  /**
   * {@inheritdoc}
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // Set up the test here.
    $this->adminUser = $this->drupalCreateUser(['administer verify email']);
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Test the Verify Email entity configuration form.
   */
  public function testVerifyEmailConfig(): void {
    // Open config page.
    $this->drupalGet('/admin/people/verify-email');
    $this->assertSession()->elementExists('xpath', '//h1[text() = "Verify Email configuration"]');
    $this->assertSession()->pageTextContains('There are no Verify Email forms yet.');
    // Add a verify email entity.
    $this->drupalGet('/admin/people/verify-email/add');
    $this->assertSession()->elementExists('xpath', '//h1[text() = "Add a verify email form"]');
    // Assert the field exists in the form.
    $this->assertSession()->fieldExists('thank_you_body');
    $edit = [
      'label' => 'Test verify email',
      'id' => 'test_verify_email',
      'path' => 'test-verify-email',
      'intro' => 'Please enter your email.',
      'email_subject' => 'Your email invite',
      'email_body' => 'Please click this link.',
      'thank_you_body' => 'Thank you message.',
      'redirect_path' => 'somewhere',
    ];
    $this->submitForm($edit, 'Save');
    $this->drupalGet('/admin/people/verify-email');
    $this->assertSession()->elementExists('xpath', '//td[text() = "Test verify email"]');
    // Update the verify email form label.
    $this->drupalGet('/admin/people/verify-email/test_verify_email');
    $this->submitForm(['label' => 'Updated label'], 'Save');
    $this->assertSession()->elementExists('xpath', '//td[text() = "Updated label"]');
    // Delete the verify email form.
    $this->drupalGet('/admin/people/verify-email/test_verify_email/delete');
    $this->assertSession()->buttonExists('Delete')->click();
    $this->assertSession()->pageTextContains('There are no Verify Email forms yet.');
  }

}
